pub enum Mode {
User,
System,
}Expand description
Whether to install system wide or for the current user only
Variants
User
install for the current user, does not require running the installation as superuser/admin
System
install to the entire system, the installation/removal must be ran as
superuser/admin or it will return
PrepareInstallError::NeedRootForSysInstall or PrepareRemoveError::NeedRoot