pub struct KillOld { /* private fields */ }Trait Implementations
Sourceimpl InstallStep for KillOld
impl InstallStep for KillOld
Sourcefn describe(&self, tense: Tense) -> String
fn describe(&self, tense: Tense) -> String
A short (one line) description of what running perform will
do. Pass in the tense you want for the description (past, present or
future)
Sourcefn perform(&mut self) -> Result<Option<Box<dyn RollbackStep>>, InstallError>
fn perform(&mut self) -> Result<Option<Box<dyn RollbackStep>>, InstallError>
Perform this install step making a change to the system. This may return
a
RollbackStep that can be used to undo the change made in the
future. This can be used in an install wizard to roll back changes when
an error happens. Read moreSourcefn describe_detailed(&self, tense: Tense) -> String
fn describe_detailed(&self, tense: Tense) -> String
A verbose description of what running perform will do to the
system. Includes as many details as possible. Pass in the tense you want
for the description (past, present or future)
Sourcefn options(&self) -> Option<StepOptions>
fn options(&self) -> Option<StepOptions>
Is this a question and if so what options does the user have for responding?