pub struct InitSystemFailure { /* private fields */ }Expand description
The init system was found and we tried to set up the service but ran into an error.
When there is another init system that does work this error is ignored. If no other system is available or there is but it/they fail too this error is reported.
A warning is always issued if the tracing feature is enabled.