InstallSteps

Struct InstallSteps 

pub struct InstallSteps(/* private fields */);
Changes to the system that need to be applied to do the installation.

Returned by Spec::prepare_install.Use install() to apply all changes at once. This implements IntoIterator yielding InstallSteps. These steps can be described possibly in detail and/or performed one by one.

Implementations

Source

impl InstallSteps

pub fn install(self) -> Result<String, InstallError>

Perform all steps needed to install.

Errors

The system can change between preparing to install and actually installing. For example all disk space could be used. Or the install could run into an error that was not checked for while preparing. If you find this happens please make an issue.