RollbackStep

Trait RollbackStep 

pub trait RollbackStep {
    // Required methods
    fn perform(&mut self) -> Result<(), RollbackError>;
    fn describe(&self, tense: Tense) -> String;
}
Undoes a InstallStep. Can be executed or described.

Required Methods

fn perform(&mut self) -> Result<(), RollbackError>

Executes this rollback step. This can be used when building an install wizard. You can describe() and then ask the end user if the want to perform it.

Errors

The system could have changed between the install and the rollback. Leading to various errors, mostly IO.

fn describe(&self, tense: Tense) -> String