pub struct InstallSteps(/* private fields */);Expand description
Changes to the system that need to be applied to do the installation.
Returned by Spec::prepare_install.Use
install() to apply all changes at once. This
implements IntoIterator yielding InstallSteps. These
steps can be described possibly in detail and/or performed one by one.
Implementations
Sourceimpl InstallSteps
impl InstallSteps
Sourcepub fn install(self) -> Result<String, Box<dyn Error + Send + Sync + 'static>>
pub fn install(self) -> Result<String, Box<dyn Error + Send + Sync + 'static>>
Perform all steps needed to install.
Errors
The system can change between preparing to install and actually installing. For example all disk space could be used. Or the install could run into an error that was not checked for while preparing. If you find this happens please make an issue.