Struct service_install::install::RemoveSteps
source · pub struct RemoveSteps(/* private fields */);Expand description
Changes to the system that need to be applied to remove the installation.
Returned by Spec::prepare_remove.Use
remove() to apply all changes at once. This
implements IntoIterator yielding RemoveSteps. These
steps can be described possibly in detail and/or performed one by one.
Implementations
sourceimpl RemoveSteps
impl RemoveSteps
sourcepub fn remove(self) -> Result<String, Box<dyn Error>>
pub fn remove(self) -> Result<String, Box<dyn Error>>
Perform all steps needed to remove an installation. Report what was done at the end. Aborts on error.
Errors
The system can change between preparing to remove and actually removing the install. For example a file could have been removed by the user of the system. Or the removal could run into an error that was not checked for while preparing. If you find this happens please make an issue.
sourcepub fn best_effort_remove(self) -> Result<String, BestEffortRemoveError>
pub fn best_effort_remove(self) -> Result<String, BestEffortRemoveError>
Perform all steps needed to remove an installation. If any fail keep going. Collect all the errors and report them at the end.
Errors
The system can change between preparing to remove and actually removing the install. For example a file could have been removed by the user of the system. Or the removal could run into an error that was not checked for while preparing. If you find this happens please make an issue.